emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master b376580e975: Prefer HTTPS to HTTP in thing-at-point


From: Stefan Kangas
Subject: master b376580e975: Prefer HTTPS to HTTP in thing-at-point
Date: Mon, 23 Oct 2023 19:06:50 -0400 (EDT)

branch: master
commit b376580e975b311390308e49a2b4c951ff6a7574
Author: Stefan Kangas <stefankangas@gmail.com>
Commit: Stefan Kangas <stefankangas@gmail.com>

    Prefer HTTPS to HTTP in thing-at-point
    
    * lisp/thingatpt.el (thing-at-point-url-at-point): Prefer HTTPS to
    HTTP.
---
 lisp/thingatpt.el | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/lisp/thingatpt.el b/lisp/thingatpt.el
index 72acb0b749f..5d4f4df9131 100644
--- a/lisp/thingatpt.el
+++ b/lisp/thingatpt.el
@@ -565,9 +565,9 @@ looks like an email address, \"ftp://\"; if it starts with
         ;; If it looks like ftp.example.com. treat it as ftp.
         (if (string-match "\\`ftp\\." str)
             (setq str (concat "ftp://"; str)))
         ;; If it looks like www.example.com. treat it as http.
         (if (string-match "\\`www\\." str)
-            (setq str (concat "http://"; str)))
+             (setq str (concat "https://"; str)))
         ;; Otherwise, it just isn't a URI.
         (setq str nil)))
       str)))
@@ -565,9 +565,9 @@ looks like an email address, \"ftp://\"; if it starts with
         (if (string-match "\\`ftp\\." str)
             (setq str (concat "ftp://"; str)))
-        ;; If it looks like www.example.com. treat it as http.
+         ;; If it looks like www.example.com. treat it as https.
         (if (string-match "\\`www\\." str)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]